@@ -1,7 +1,7 @@
+use super::*;
 use std::collections::BTreeMap;
 
-use super::*;
-
+#[derive(Clone, PartialEq)]
 pub struct Op {
     phases: BTreeMap<N, C>,
 }
@@ -18,15 +18,10 @@ impl Op {
                 jdx <<= 1;
             }
         }
-        phases.iter_mut().for_each(|(_, val)| *val = C::from_polar(1.0, val.im));
-        Self{ phases }
-    }
-}
-
-impl Into<SingleOp> for Op {
-    fn into(self) -> SingleOp {
-        let act = self.phases.iter().fold(0, |act, (i, _)| act | *i);
-        SingleOp { act, ctrl: 0, func: Ptr::new(self) }
+        phases
+            .iter_mut()
+            .for_each(|(_, val)| *val = C::from_polar(1.0, val.im));
+        Self { phases }
     }
 }
 
@@ -45,7 +40,21 @@ impl AtomicOp for Op {
         format!("Phase{:?}", self.phases)
     }
 
-    fn dgr(self: Ptr<Self>) -> Ptr<dyn AtomicOp> {
-        Ptr::new(Self{ phases: self.phases.iter().map(|(idx, ang)| (*idx, ang.conj())).collect() })
+    fn acts_on(&self) -> N {
+        self.phases.iter().fold(0, |acc, idx| acc | *idx.0)
     }
-}
\ No newline at end of file
+
+    fn this(self) -> AtomicOpDispatch {
+        AtomicOpDispatch::Phi(self)
+    }
+
+    fn dgr(self) -> AtomicOpDispatch {
+        AtomicOpDispatch::Phi(Self {
+            phases: self
+                .phases
+                .into_iter()
+                .map(|(idx, ang)| (idx, ang.conj()))
+                .collect(),
+        })
+    }
+}
