@@ -1,6 +1,7 @@
-use {
-    crate::math::{C, N, R},
-    super::*
+use super::*;
+use crate::{
+    math::{C, N, R},
+    operator::single::pauli::phi,
 };
 
 pub fn qft(a_mask: N) -> MultiOp {
@@ -19,16 +20,18 @@ pub fn qft(a_mask: N) -> MultiOp {
                 }
             }
 
-            for i in 0..(count-1) {
+            for i in 0..(count - 1) {
                 res.append(&mut h::h(vec[i]).0);
                 res.push_back(
-                    crate::operator::single::pauli::phi(
-                        ((i + 1)..count).map(|j| (crate::math::PI * 0.5f64.powi((j - i) as i32), vec[j])).collect())
-                        .c(vec[i]).unwrap()
+                    phi(((i + 1)..count)
+                        .map(|j| (crate::math::PI * 0.5f64.powi((j - i) as i32), vec[j]))
+                        .collect())
+                    .c(vec[i])
+                    .unwrap(),
                 );
             }
 
-            res.append(&mut h::h(vec[count-1]).0);
+            res.append(&mut h::h(vec[count - 1]).0);
             MultiOp(res)
         }
     }
