@@ -1,35 +1,34 @@
-use std::borrow::Borrow;
 use crate::{
+    math::{C, N, R},
     operator::{atomic, single::*},
-    math::{C, R, N},
 };
 
 #[inline(always)]
-pub (crate) fn x(a_mask: N) -> SingleOp {
+pub fn x(a_mask: N) -> SingleOp {
     atomic::x::Op::new(a_mask).into()
 }
 
 #[inline(always)]
-pub (crate) fn y(a_mask: N) -> SingleOp {
+pub fn y(a_mask: N) -> SingleOp {
     atomic::y::Op::new(a_mask).into()
 }
 
 #[inline(always)]
-pub (crate) fn z(a_mask: N) -> SingleOp {
+pub fn z(a_mask: N) -> SingleOp {
     atomic::z::Op::new(a_mask).into()
 }
 
 #[inline(always)]
-pub (crate) fn s(a_mask: N) -> SingleOp {
+pub fn s(a_mask: N) -> SingleOp {
     atomic::s::Op::new(a_mask).into()
 }
 
 #[inline(always)]
-pub (crate) fn t(a_mask: N) -> SingleOp {
+pub fn t(a_mask: N) -> SingleOp {
     atomic::t::Op::new(a_mask).into()
 }
 
 #[inline(always)]
-pub (crate) fn phi(phases: Vec<(R, N)>) -> SingleOp {
+pub fn phi(phases: Vec<(R, N)>) -> SingleOp {
     atomic::phi::Op::new(phases).into()
-}
\ No newline at end of file
+}
